<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 */


function sqlImport($file) {

$delimiter = ';';
$file = fopen($file, 'r');
$isFirstRow = true;
$isMultiLineComment = false;
$sql = '';

while (!feof($file)) {

$row = fgets($file);

// remove BOM for utf-8 encoded file
if ($isFirstRow) {
$row = preg_replace('/^\x{EF}\x{BB}\x{BF}/', '', $row);
$isFirstRow = false; }

// 1. ignore empty string and comment row
if (trim($row) == '' || preg_match('/^\s*(#|--\s)/sUi', $row)) {
continue; }

// 2. clear comments
$row = trim(clearSQL($row, $isMultiLineComment));

// 3. parse delimiter row
if (preg_match('/^DELIMITER\s+[^ ]+/sUi', $row)) {
$delimiter = preg_replace('/^DELIMITER\s+([^ ]+)$/sUi', '$1', $row);
continue; }

// 4. separate sql queries by delimiter
$offset = 0;
while (strpos($row, $delimiter, $offset) !== false) {
$delimiterOffset = strpos($row, $delimiter, $offset);
if (isQuoted($delimiterOffset, $row)) {
$offset = $delimiterOffset + strlen($delimiter);
} else {
$sql = trim($sql . ' ' . trim(substr($row, 0, $delimiterOffset)));
query($sql);

$row = substr($row, $delimiterOffset + strlen($delimiter));
$offset = 0;
$sql = ''; }}
$sql = trim($sql . ' ' . $row); }
if (strlen($sql) > 0) {
query($row); }

fclose($file); }

/**
 * Remove comments from sql
 *
 * @param string sql
 * @param boolean is multicomment line
 * @return string
 */
function clearSQL($sql, &$isMultiComment) {
if ($isMultiComment) {
if (preg_match('#\*/#sUi', $sql)) {
$sql = preg_replace('#^.*\*/\s*#sUi', '', $sql);
$isMultiComment = false;
} else {
$sql = ''; }
if (trim($sql) == '') {
return $sql; }}

$offset = 0;
while (preg_match('{--\s|#|/\*[^!]}sUi', $sql, $matched, PREG_OFFSET_CAPTURE, $offset)) {
list($comment, $foundOn) = $matched[0];
if (isQuoted($foundOn, $sql)) {
$offset = $foundOn + strlen($comment);
} else {
if (substr($comment, 0, 2) == '/*') {
$closedOn = strpos($sql, '*/', $foundOn);
if ($closedOn !== false) {
$sql = substr($sql, 0, $foundOn) . substr($sql, $closedOn + 2);
} else {
$sql = substr($sql, 0, $foundOn);
$isMultiComment = true; }
} else {
$sql = substr($sql, 0, $foundOn);
break; }}}
return $sql; }

/**
 * Check if "offset" position is quoted
 *
 * @param int $offset
 * @param string $text
 * @return boolean
 */
function isQuoted($offset, $text) {
if ($offset > strlen($text))
$offset = strlen($text);

$isQuoted = false;
for ($i = 0; $i < $offset; $i++) {
if ($text[$i] == "'")
$isQuoted = !$isQuoted;
if ($text[$i] == "\\" && $isQuoted)
$i++; }
return $isQuoted; }

function query($sql) {
global $mysqli;
//echo '#<strong>SQL CODE TO RUN:</strong><br>' . htmlspecialchars($sql) . ';<br><br>';
if (!$query = $mysqli->query($sql)) {
throw new Exception("Cannot execute request to the database {$sql}: " . $mysqli->error); }}

set_time_limit(0);

require_once '../builders/config.php';

$mysqli->set_charset("utf8");
header('Content-Type: text/html;charset=utf-8');
sqlImport('spectra.sql'); ?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta http-equiv="x-ua-compatible" content="ie=edge">
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no" />
<title>Setup Installation</title>
<link rel="stylesheet" href="style.css" />
</head>
<body>

<div class="radius wrapper spacer">

<br>
<div class="radius spacer center" style="height:500px">
<header>
<h1 class="center">Setup Installation</h1>
</header>
<br>
<br>
<section>
<p>Your Database has been populated successfully.</p>
<br>
<?php echo "Peak Usage MB: ", memory_get_peak_usage(true) / 1024 / 1024; ?>
</section>

<section class="button">
<div class="center"><a href="lang.php" style="text-decoration:none"><span class="white">Continue</span></a></div>
</section>
</div>
</div>
