<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 */

include_once '../builders/config.php';

/**
 * 
 * Now we check if the data was submitted, 
 * isset() function will check if the data exists.
 * 
 */

if (!isset($_POST['username'], $_POST['password'], $_POST['email'])) {

/**
 * 
 * Could not get the data that should have been sent.
 * 
 */

exit('' . _COMPLETEFORM . ''); }

/**
 * 
 * Make sure the submitted registration values are not empty.
 * 
 */

if (empty($_POST['username']) || empty($_POST['password']) || empty($_POST['email'])) {

/**
 * 
 * One or more values are empty.
 * 
 */

exit('' . _COMPLETEFORM . ''); }

/**
 * 
 * Check to see if the email is valid.
 * 
 */

if (!filter_var($_POST['email'], FILTER_VALIDATE_EMAIL)) {
exit('' .  _EMAILNOTVALID . ''); }

/**
 * 
 * Username must contain only characters and numbers.
 * 
 */

if (preg_match('/[A-Za-z0-9]+/', $_POST['username']) == 0) {
exit('' . _USERNAMENOTVALID . ''); }

/**
 * 
 * Password must be between 5 and 20 characters long.
 * 
 */

if (strlen($_POST['password']) > 20 || strlen($_POST['password']) < 5) {
exit('' . _PASSWORDMUSTBE . ''); }

/**
 * 
 * We need to check if the account with that username exists.
 * 
 */

if ($stmt = $conn->prepare('SELECT id, password FROM accounts WHERE username = ?')) {

/**
 * 
 * Bind parameters (s = string, i = int, b = blob, etc), 
 * hash the password using the PHP password_hash function.
 * 
 */

$stmt->bind_param('s', $_POST['username']);
$stmt->execute();
$stmt->store_result();

/**
 * 
 * Store the result so we can check if the account exists in the database.
 * 
 */

if ($stmt->num_rows > 0) {

/**
 * 
 * Username already exists.
 * 
 */

echo '' . _USERNAMEEXISTS . '';
} else {

/**
 * 
 * Username doesn't exists, insert new account.
 * 
 */

if ($stmt = $conn->prepare('INSERT INTO accounts (username, password, email, activation_code, role) VALUES (?, ?, ?, ?, ?)')) {

/**
 * 
 * We do not want to expose passwords in our database, 
 * so hash the password and use password_verify when a user logs in.
 * 
 */

$password = password_hash($_POST['password'], PASSWORD_DEFAULT);
$stmt->bind_param('sssss', $_POST['username'], $password, $_POST['email'], $_POST['activation_code'], $_POST['role']);
$stmt->execute();
require_once 'admin-successful.php';
} else {

/**
 * 
 * Something is wrong with the sql statement, 
 * check to make sure accounts table exists with all 3 fields.
 * 
 */

echo '' . _COULDNOTPREPARE .''; }}
} else {

/**
 * 
 * Something is wrong with the sql statement, 
 * check to make sure accounts table exists with all fields.
 * 
 */

echo '' . _COULDNOTPREPARE .''; }
